@@ -25,11 +25,16 @@ def test_distance_function_exceptions(condition, text):
 	[
 		("Hugin |w5 Munin", "Odin had two ravens Hugin and Munin", True),
 		("Hugin |c5 Munin", "Odin had two ravens Hugin and Munin", True),
+		("Hugin |w5 Munin", "Odin had two ravens Munin and Hugin", True),
+		("Hugin |c5 Munin", "Odin had two ravens Munin and Hugin", True),
 		("Hugin |w15 Munin", "", False),
 		("Hugin |c15 Munin", "", False),
 		("Munin |w0 Hugin", "Munin Hugin", True),
+		("Munin |w0 Hugin", "Hugin Munin", True),
 		("Munin |w0 Hugin", "Munin and Hugin", False),
 		("T |c0 wo", "Two", True),
+		("Hello world |w0 how are you", "Hello world how are you", True),
+		("how are you |w0 Hello world", "Hello world how are you", True),
 	]
 )
 def test_distance_function_results(condition, text, expected_result):
