@@ -23,6 +23,10 @@ def test_nearby_function_exceptions(condition, text):
 		("Hugin, |nearby Munin", "Odin had two ravens Hugin, Munin", True),
 		("Odin had son. And he was |nearby Tor | Vali | Vidar | Heimdall | Bragi | Tur", "Odin had son. And he was Tor", True),
 		("Odin had son. And he was |nearby Tor | Vali | Vidar | Heimdall | Bragi | Tur", "Odin had son. And he was UNKNOWN", False),
+		("elephant |nearby buy | well buy", "buy elephant", True),
+		("elephant |nearby buy | well buy", "elephant buy", True),
+		("elephant |nearby buy | well buy", "well buy elephant", True),
+		("elephant |nearby buy | well buy", "elephant well buy", True),
 	]
 )
 def test_nearby_function_results(condition, text, expected_result):
